summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/groupwise/libgroupwise/gwfield.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/groupwise/libgroupwise/gwfield.h')
-rw-r--r--kopete/protocols/groupwise/libgroupwise/gwfield.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/protocols/groupwise/libgroupwise/gwfield.h b/kopete/protocols/groupwise/libgroupwise/gwfield.h
index 6d3cb5a9..4e1b1f94 100644
--- a/kopete/protocols/groupwise/libgroupwise/gwfield.h
+++ b/kopete/protocols/groupwise/libgroupwise/gwfield.h
@@ -194,18 +194,18 @@ namespace Field
*/
virtual ~FieldList();
/**
* Locate the first occurrence of a given field in the list. Same semantics as TQValueList::tqfind().
* @param tag The tag name of the field to search for.
* @return An iterator pointing to the first occurrence found, or end() if none was found.
*/
- FieldListIterator tqfind( TQCString tag );
+ FieldListIterator find( TQCString tag );
/**
* Locate the first occurrence of a given field in the list, starting at the supplied iterator
* @param tag The tag name of the field to search for.
* @param it An iterator within the list, to start searching from.
* @return An iterator pointing to the first occurrence found, or end() if none was found.
*/
- FieldListIterator tqfind( FieldListIterator &it, TQCString tag );
+ FieldListIterator find( FieldListIterator &it, TQCString tag );
/**
* Get the index of the first occurrence of tag, or -1 if not found
*/
@@ -194,18 +194,18 @@ namespace Field
virtual ~FieldList();
/**
- * Locate the first occurrence of a given field in the list. Same semantics as TQValueList::tqfind().
+ * Locate the first occurrence of a given field in the list. Same semantics as TQValueList::find().
* @param tag The tag name of the field to search for.
* @return An iterator pointing to the first occurrence found, or end() if none was found.